#[non_exhaustive]pub struct ContentPurpose(pub u32);Expand description
content purpose
The content purpose allows to specify the primary purpose of a text input.
This allows an input method to show special purpose input panels with extra characters or to disallow some characters.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: u32Implementations